==> owncloud_6.0.4~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/ar.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "جهات الاتصال",
"Save" => "حفظ",
"Uploading..." => "ترفيع...",
"Importing..." => "استيراد...",
"Preparing..." => "إعداد...\nتحضير...",
"Imported {count} of {total} contacts" => "استيراد {عدد} من {إجمالي} جهات الإتصال",
"Imported {imported} contacts. {failed} failed." => "فلشت {failed}  مهمة اسيراد جهات الإتصال {imported}",
"An address book called {name} already exists" => " دفتر العناوين يحمل  {اسم } موجود مسبقاً",
"Failed adding address book: {error}" => "{خطأ} فشلت مهمة إضافة عنوان ",
"Failed loading address books: {error}" => "{خطأ} فشلت مهمة تحميل دفتر العناوين",
"Indexing contacts" => "فهرسة جهات الاتصال",
"Unrecoverable error loading address books: {msg}" => "حدث خطأ فادح أثناء تحميل دفتر العناوين: {msg}",
"Error." => "خطأ.",
"Add to..." => "إضافة إلى...",
"Remove from..." => "الحذف من ...",
"Add group..." => "إضافة مجموعة ...",
"Invalid URL: \"{url}\"" => "الرابط غير صحيح: \"{url}\"",
"There was an error opening a mail composer." => "يوجد خطأ في فتح مؤلف الرسائل",
"Invalid email: \"{url}\"" => "رابط البريد الإلكتروني غير صالح:  \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "عملية الدمج فشلت. لا يمكن إيجاد جهة الاتصال: {id}",
"Merge failed." => "علمية الدمج فشلت.",
"Merge failed. Error saving contact." => "عملية الدمج فشلت. خطأ في حفظ جهة الاتصال. ",
"Select photo" => "اختر صورة",
"Network or server error. Please inform administrator." => "حدث خطأ في شبكة الاتصال أو في الخادم. يرجى إبلاغ المسؤول.",
"Error adding to group." => "خطأ في إضافة المجموعة",
"Error removing from group." => "حدث خطأ أثناء الحذف من المجموعة",
"Error setting {name} as favorite." => "حدث خطأ أثناء إعداد {name} كمفضلة .",
"Merge contacts" => "دمج جهات الاتصال",
"Cancel" => "الغاء",
"Add group" => "إضافة مجموعة",
"OK" => "تم",
"Could not find contact: {id}" => "تعذر ايجاد جهة الاتصال:  {id}",
"No files selected for upload." => "لا يوجد ملفات مختارة لتحميلها",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "الملف الذي تحاول تحميله يتجاوز الحد الأقصى لحجم الملف الذي يمكن تحميله على هذا الخادم.",
"Edit profile picture" => "تعديل صورة الملف الشخصي",
"Crop photo" => "قص الصورة.",
"Is this correct?" => "هل هذا صحيح؟",
"# groups" => "#المجموعات",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "بعض جهات الأتصال تم تحديدها للحذف لكن لم يتم حذفها بعد. يرجى الانتظار قليلاً حتى يتم حذفها بالكامل.",
"Click to undo deletion of {num} contacts" => "إضغط حتى يتم التراجع عن حذف {أرقام} جهات الاتصال",
"Cancelled deletion of {num} contacts" => "ألغاء حذف {num}  من جهات الاتصال.",
"Add" => "اضف",
"Contact is already in this group." => "جهة الاتصال موجودة بالفعل في هذه المجموعة.",
"Contacts are already in this group." => "جهات الاتصال موجودة بالفعل في هذه المجموعة.",
"Couldn't get contact list." => "تعذر الحصول على قائمة جهات الاتصال.",
"Contact is not in this group." => "جهة الاتصال غير موجودة في هذه المجموعة. ",
"Contacts are not in this group." => "جهات الاتصال غير موجودة في هذه المجموعة. ",
"Failed renaming group: {error}" => "{خطأ}: فشلت مهمة تغيير اسم المجموعة",
"A group named {group} already exists" => "اسم المجموعة { مجموعة } موجود مسبقاً.",
"You can drag groups to\narrange them as you like." => "يمكنك سحب المجموعات إلى⏎\nو من ثم ترتيبها كما تريد.",
"Failed adding group: {error}" => "{خطأ}: فشلت مهمة إضافة مجموعة. ",
"All" => "الكل",
"Favorites" => "المفضلة ",
"Shared by {owner}" => "مشاركة بواسطة المالك  {owner}",
"Not grouped" => "غير مصنف",
"Failed loading groups: {error}" => "{خطأ}: فشلت مهمة تجميل المجموعات.",
"Please choose the addressbook" => "يرجى اختيار دفتر العناوين",
"Import into..." => "استيراد إلى...",
"Error loading import template" => "خطأ في تحميل نموذج الاستيراد",
"Import contacts" => "استيراد جهات الإتصال.",
"Import" => "استيراد",
"Import done" => "تمت عملية الاستيراد ",
"Close" => "إغلاق",
"Error" => "خطأ",
"Displayname cannot be empty." => "اسم العرض لا يمكن أن يكون فارغ ",
"Show CardDav link" => "أظهر وصلة -رابط - CardDav لمشاركة أو نقل جهات الاتصال.",
"Download" => "تحميل",
"Edit" => "تعديل",
"Delete" => "إلغاء",
"More..." => "المزيد...",
"Less..." => "تقليل...",
"Server error! Please inform system administator" => "خطأ في الخادم! يرجى ابلاغ مدير النظام.",
"Failed loading photo: {error}" => "{خطأ}: فشلت مهمة تحميل الصورة",
"You do not have permissions to see this contacts" => "ليس لديك الصلاحية  لمشاهدة جهة الاتصال هذه",
"Contact not found" => "تعذر إيجاد جهة الاتصال.",
"You do not have permissions to see these contacts" => "ليس لديك الصلاحية  لمشاهدة جهات الاتصال هذه",
"You do not have permissions add contacts to the address book" => "ليس لديك الصلاحية  لإضافة جهات اتصال لدفتر العناوين",
"You do not have permissions to delete this contact" => "ليس لديك الصلاحية  لحذف جهة الاتصال",
"Unknown error" => "حدث خطأ غير معروف. ",
"You don't have permissions to update the address book." => "ليس لديك الصلاحية  لتحديث دفتر العناوين",
"You don't have permissions to delete the address book." => "ليس لديك الصلاحية  لحذف دفتر العناوين.",
"Address book not found" => "تعذر ايجاد دفتر العناوين",
"You do not have permissions to see this contact" => "ليس لديك الصلاحية  لمشاهدة جهة الاتصال ",
"You do not have permissions to update this contact" => "ليس لديك الصلاحية  لتحديث جهة الاتصال هذه",
"Property not found" => "لم يتم العثور على الملكية",
"Unknown IM: " => "جهة تراسل فوري غير معروفة",
"{name}'s Birthday" => "يوم ميلاد {name}'s",
"Error creating address book" => "خطأ في إنشاء دفتر العناوين",
"Error updating address book" => "حدث خطأ في تحديث دفتر العناوين",
"You do not have permissions to delete the \"%s\" address book" => "ليس لديك الصلاحية لحذف  \"%s\" دفتر العناوين",
"Error deleting address book" => "حدث خطأ أثناء إزالة دفتر العناوين",
"Error creating contact." => "حدث خطأ أثناء إنشاء جهة اتصال.",
"Error deleting contact." => "خطأ في حذف جهة الاتصال",
"Error retrieving contact." => "حدث خطأ أثناء استرداد جهة الاتصال.",
"Error saving contact." => "خطأ في حفظ جهة الإتصال.",
"Error removing contact from other address book." => "حدث خطأ أثناء إزالة جهة اتصال من دفتر العناوين.",
"Couldn't find contact." => "تعذر ايجاد جهة الاتصال",
"Information about vCard is incorrect. Please reload the page." => "المعلومات الموجودة في ال vCard غير صحيحة. الرجاء إعادة تحديث الصفحة.",
"Error updating contact" => "خطأ في تحديث جهات الاتصال",
"Error saving contact to backend" => "حدث خطأ أثناء حفظ جهات الاتصال في الخلفية.",
"Error getting user photo" => "حدث خطأ أثناء جلب صورة المستخدم",
"No file was uploaded. Unknown error" => "لم يتم رفع أي ملف , خطأ غير معروف",
"There is no error, the file uploaded with success" => "تم ترفيع الملفات بنجاح.",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "حجم الملف الذي تريد ترفيعه أعلى مما upload_max_filesize يسمح به في ملف php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "حجم الملف الذي تريد ترفيعه أعلى مما MAX_FILE_SIZE يسمح به في واجهة ال HTML.",
"The uploaded file was only partially uploaded" => "تم ترفيع جزء من الملفات الذي تريد ترفيعها فقط",
"No file was uploaded" => "لم يتم ترفيع أي من الملفات",
"Missing a temporary folder" => "المجلد المؤقت غير موجود",
"Couldn't load temporary image: " => "لا يمكن تحميل الصورة المؤقتة",
"Couldn't save temporary image: " => "لا يمكن حفظ الصورة المؤقتة ",
"No photo path was submitted." => "لم يتم عرض مسار الصورة. \nلم يتم تقديم مسار للصورة. ",
"File doesn't exist:" => "الملف غير موجود",
"Error loading image." => "خطأ في تحميل الصورة. ",
"Image has been removed from cache" => "تم إزالة الصورة من ذاكرة التخزين المؤقتة. ",
"Error creating temporary image" => "خطأ في إنشاء صورة مؤقتة ",
"Error cropping image" => "خطأ في قص الصورة",
"Error resizing image" => "خطأ في تغيير حجم الصورة",
"Error getting PHOTO property." => "خطأ في الحصول على ملكية الصورة.",
"No group name given." => "لم يتم تسمية المجموعة بعد.",
"Error adding group." => "حدث خطأ أثناء إضافة المجموعة,",
"Error renaming group." => "حدث خطأ أثناء إعادة تسمية المجموعة.",
"Failed to write to disk" => "خطأ في الكتابة على القرص الصلب",
"Not enough storage available" => "لا يوجد مساحة تخزينية كافية",
"Error uploading contacts to storage." => "خطأ في رفع جهات الإتصال للمخزن,",
"Error moving file to imports folder." => "خطأ في نقل الملف إلى مجلد الاستيراد.",
"No contacts found in: " => "لم يتم إيجاد جهات اتصال في:",
"Could not set preference: " => "تعذر تعيين المفضل ",
"Contact" => "معرفه",
"Other" => "شيء آخر",
"HomePage" => "الصفحة الرئيسية",
"Internet call" => "مكالمات عن طريق الإنترنت",
"MSN" => "مراسل MSN",
"Twitter" => "تويتر",
"GoogleTalk" => "جوجل توك للتراسل الفوري و الصوتي",
"Facebook" => "فيسبوك",
"ICQ" => "ICQ",
"Yahoo" => "ياهو",
"Skype" => "سكايب",
"QQ" => "كيوكيو",
"GaduGadu" => "قادو قادو البولندي للمراسلة الفورية",
"Work" => "العمل",
"Home" => "البيت",
"Mobile" => "الهاتف المحمول",
"Text" => "معلومات إضافية",
"Voice" => "صوت",
"Message" => "رسالة",
"Fax" => "الفاكس",
"Video" => "الفيديو",
"Pager" => "الرنان",
"Internet" => "إنترنت",
"Friends" => "الاصدقاء",
"Family" => "العائلة",
"New Contact" => "جهة اتصال جديدة",
"Group name" => "اسم المجموعة",
"New Group" => "مجموعة جديدة",
"Address books" => "دفتر العناوين",
"Display name" => "اسم العرض",
"Add Address Book" => "أضف دفتر عناوين جديد",
"Select file..." => "تحديد ملف...",
"(De-)select all" => "(De-) تحديد الكل",
"Sort order" => "* ترتيب.\n* فرز.",
"First- Lastname" => "الاسم الأول - العائلة",
"Last-, Firstname" => "العائلة -الاسم الأول",
"Groups" => "مجموعات",
"Favorite" => "المفضلة",
"Merge selected" => "تم تحديد الدمج",
"Keyboard shortcuts" => "اختصارات لوحة المفاتيح",
"Navigation" => "تصفح",
"Next contact in list" => "جهة الاتصال التالية في القائمة ",
"Previous contact in list" => "جهة الاتصال السابقة في القائمة ",
"Expand/collapse current addressbook" => "توسيع / طي دفتر العناوين الحالي.",
"Next addressbook" => "دفتر العنوان التالي",
"Previous addressbook" => "دفتر العنوان السابق",
"Actions" => "* تطبيقات.\n* أنشطة.",
"Refresh contacts list" => "تحديث قائمة جهات الاتصال",
"Add new contact" => "أَف جهة اتصال جديدة",
"Add new addressbook" => "أضف دفتر عناوين جديد",
"Delete current contact" => "إزالة جهة الاتصال الحالية",
"<h3>You have no contacts in your address book or your address book is disabled.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>" => "<h3>لا يوجد لديك جهات اتصال في دفتر العناوين أو أن دفتر العناوين معطل. </h3><p> يرجى إضافة جهات اتصال جديدة أو استيراد جهات الاتصال الموجودة من ملف  VCF . \n</p> ",
"Add contact" => "أضف جهة اتصال",
"Delete group" => "إزالة المجموعة",
"Rename group" => "إعادة تسمية المجموعة",
"Which contact should the data be merged into?" => "إي جهة اتصال ترغب بدمج البيانات إليها؟",
"Delete the other(s) after successful merge?" => "هل تريد إزالة (الآخرون) بعد نجاح عملية الدمج؟",
"Compose mail" => "إنشاء رسالة بريد إلكتروني",
"Delete current photo" => "إزالة الصورة الحالية",
"Edit current photo" => "تحرير الصورة الحالية",
"Upload new photo" => "رفع صورة جديدة",
"Select photo from ownCloud" => "إختيار صورة من ownCloud",
"Name" => "اسم",
"First name" => "الاسم الأول",
"Additional names" => "الاسماء الإضافية",
"Last name" => "اسم العائلة",
"Select groups" => "إختر مجموعة",
"Select address book" => "إختيار دفتر عناوين",
"Nickname" => "كنية.\nلقب.",
"Enter nickname" => "أدخل كنية.",
"Title" => "اللقب",
"Enter title" => "أدخل لقب.",
"Organization" => "المؤسسة",
"Enter organization" => "أدخل اسم المنظمة",
"Birthday" => "عيد ميلاد",
"Notes go here..." => "للملاحظات إذهب هنا...",
"Export as VCF" => "تصدير كملف VCF",
"Phone" => "الهاتف",
"Email" => "البريد الإلكترونى",
"Instant Messaging" => "التراسل الفوري",
"Address" => "عنوان",
"Note" => "ملاحظة",
"Web site" => "موقع إلكتروني",
"Delete contact" => "امحي المعرفه",
"Preferred" => "مفضل",
"Please specify a valid email address." => "يرجى تحديد عنوان إلكتروني صالح للإستخدام.",
"someone@example.com" => "someone@example.com",
"Mail to address" => "إرسال إلى العنوان.",
"Delete email address" => "حذف عنوان البريد الإلكتروني",
"Enter phone number" => "إدخال رقم الهاتف",
"Delete phone number" => "حذف رقم الهاتف",
"Go to web site" => "الذهاب إلى الموقع الإلكتروني.",
"Delete URL" => "حذف رابط URL",
"View on map" => "مشاهدة على الخريطة.",
"Delete address" => "حذف العنوان",
"1600 Pennsylvania Avenue, NW" => "* 1600شمالي غرب جادة بنسلفانيا.\n* البيت الأبيض",
"Street address" => "عنوان الشارع.",
"20500" => "20500",
"Postal code" => "الرمز البريدي.",
"Washington, DC" => "العاصمة واشنطن. ",
"City" => "المدينة",
"District of Columbia" => " قطاع كولومبيا",
"State or province" => "الولاية أو المنطقة.",
"USA" => "الولايات المتحدة الأمريكية.",
"Country" => "البلد",
"Instant Messenger" => "رسائل فورية.",
"Delete IM" => "حذف الرسائل الفورية.",
"Active" => "فعال",
"Share" => "شارك",
"Export" => "تصدير",
"CardDAV link" => "رابط - وصلة - CardDA لنقل و مشاركة جهات الاتصال",
"CardDAV syncing addresses" => "CardDAV يقوم بمزامنة العناوين",
"more info" => "مزيد من المعلومات",
"Primary address (Kontact et al)" => "العنوان الرئيسي (جهات الإتصال)",
"iOS/OS X" => "ط ن ت/ ن ت 10",
"Addressbooks" => "كتب العناوين",
"New Address Book" => "كتاب عناوين جديد",
"Description" => "مواصفات"
);

==> owncloud_7.0.0~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/ar.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "جهات الاتصال",
"Ok" => "موافق",
"Cancel" => "الغاء",
"Save" => "حفظ",
"Edit Addressbook" => "عدل كتاب العناوين",
"An address book called {name} already exists" => " دفتر العناوين يحمل  {اسم } موجود مسبقاً",
"Failed adding address book: {error}" => "{خطأ} فشلت مهمة إضافة عنوان ",
"Failed loading address books: {error}" => "{خطأ} فشلت مهمة تحميل دفتر العناوين",
"Server error! Please inform system administator" => "خطأ في الخادم! يرجى ابلاغ مدير النظام.",
"Indexing contacts" => "فهرسة جهات الاتصال",
"Unrecoverable error loading address books: {msg}" => "حدث خطأ فادح أثناء تحميل دفتر العناوين: {msg}",
"Error." => "خطأ.",
"Add to..." => "إضافة إلى...",
"Remove from..." => "الحذف من ...",
"Add group..." => "إضافة مجموعة ...",
"Invalid URL: \"{url}\"" => "الرابط غير صحيح: \"{url}\"",
"Invalid email: \"{url}\"" => "رابط البريد الإلكتروني غير صالح:  \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "عملية الدمج فشلت. لا يمكن إيجاد جهة الاتصال: {id}",
"Merge failed." => "علمية الدمج فشلت.",
"Merge failed. Error saving contact." => "عملية الدمج فشلت. خطأ في حفظ جهة الاتصال. ",
"Select photo" => "اختر صورة",
"Network or server error. Please inform administrator." => "حدث خطأ في شبكة الاتصال أو في الخادم. يرجى إبلاغ المسؤول.",
"Error adding to group." => "خطأ في إضافة المجموعة",
"Error removing from group." => "حدث خطأ أثناء الحذف من المجموعة",
"You have selected over 300 contacts.\nThis will most likely fail! Click here to try anyway." => "لقد قمت بتحديد أكثر من 300 جهة إتصال.\nفي العادة سوف يفشل! إضغط هنا للمحاولة على أي حال.",
"Error setting {name} as favorite." => "حدث خطأ أثناء إعداد {name} كمفضلة .",
"Merge contacts" => "دمج جهات الاتصال",
"Add group" => "إضافة مجموعة",
"OK" => "تم",
"Could not find contact: {id}" => "تعذر ايجاد جهة الاتصال:  {id}",
"Edit profile picture" => "تعديل صورة الملف الشخصي",
"Crop photo" => "قص الصورة.",
"# groups" => "#المجموعات",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "بعض جهات الأتصال تم تحديدها للحذف لكن لم يتم حذفها بعد. يرجى الانتظار قليلاً حتى يتم حذفها بالكامل.",
"Click to undo deletion of {num} contacts" => "إضغط حتى يتم التراجع عن حذف {أرقام} جهات الاتصال",
"Cancelled deletion of {num} contacts" => "ألغاء حذف {num}  من جهات الاتصال.",
"Add" => "اضف",
"Contact is already in this group." => "جهة الاتصال موجودة بالفعل في هذه المجموعة.",
"Contacts are already in this group." => "جهات الاتصال موجودة بالفعل في هذه المجموعة.",
"Couldn't get contact list." => "تعذر الحصول على قائمة جهات الاتصال.",
"Contact is not in this group." => "جهة الاتصال غير موجودة في هذه المجموعة. ",
"Contacts are not in this group." => "جهات الاتصال غير موجودة في هذه المجموعة. ",
"Failed renaming group: {error}" => "{خطأ}: فشلت مهمة تغيير اسم المجموعة",
"You can drag groups to\narrange them as you like." => "يمكنك سحب المجموعات إلى⏎\nو من ثم ترتيبها كما تريد.",
"Failed adding group: {error}" => "{خطأ}: فشلت مهمة إضافة مجموعة. ",
"All" => "الكل",
"Favorites" => "المفضلة ",
"Shared by {owner}" => "مشاركة بواسطة المالك  {owner}",
"Not grouped" => "غير مصنف",
"Failed loading groups: {error}" => "{خطأ}: فشلت مهمة تجميل المجموعات.",
"Please choose the addressbook" => "يرجى اختيار دفتر العناوين",
"Import into..." => "استيراد إلى...",
"Error loading import template" => "خطأ في تحميل نموذج الاستيراد",
"Import contacts" => "استيراد جهات الإتصال.",
"Import" => "استيراد",
"Importing..." => "استيراد...",
"Import done" => "تمت عملية الاستيراد ",
"Close" => "إغلاق",
"Failed loading photo: {error}" => "{خطأ}: فشلت مهمة تحميل الصورة",
"You do not have permissions to see this contact" => "ليس لديك الصلاحية  لمشاهدة جهة الاتصال ",
"Contact not found" => "تعذر إيجاد جهة الاتصال.",
"You do not have permissions to see these contacts" => "ليس لديك الصلاحية  لمشاهدة جهات الاتصال هذه",
"You do not have permissions add contacts to the address book" => "ليس لديك الصلاحية  لإضافة جهات اتصال لدفتر العناوين",
"You do not have permissions to delete this contact" => "ليس لديك الصلاحية  لحذف جهة الاتصال",
"Unknown error" => "حدث خطأ غير معروف. ",
"Access denied" => "الوصول محظور",
"You don't have permissions to delete the address book." => "ليس لديك الصلاحية  لحذف دفتر العناوين.",
"Address book not found" => "تعذر ايجاد دفتر العناوين",
"You do not have permissions to update this contact" => "ليس لديك الصلاحية  لتحديث جهة الاتصال هذه",
"Property not found" => "لم يتم العثور على الملكية",
"Unknown IM: " => "جهة تراسل فوري غير معروفة",
"{name}'s Birthday" => "يوم ميلاد {name}'s",
"Error creating address book" => "خطأ في إنشاء دفتر العناوين",
"You do not have permissions to delete the \"%s\" address book" => "ليس لديك الصلاحية لحذف  \"%s\" دفتر العناوين",
"Error deleting address book" => "حدث خطأ أثناء إزالة دفتر العناوين",
"Error creating contact." => "حدث خطأ أثناء إنشاء جهة اتصال.",
"Error creating contact" => "حدث خطأ أثناء إنشاء جهة الإتصال",
"Error deleting contact" => "حدث خطأ أثناء حذف جهة الإتصال",
"Error retrieving contact" => "حدث خطأ أثناء إسترداد جهة الإتصال",
"Error saving contact" => "حدث خطأ أثناء حفظ جهة الإتصال",
"Error removing contact from other address book." => "حدث خطأ أثناء إزالة جهة اتصال من دفتر العناوين.",
"Couldn't find contact." => "تعذر ايجاد جهة الاتصال",
"Information about vCard is incorrect. Please reload the page." => "المعلومات الموجودة في ال vCard غير صحيحة. الرجاء إعادة تحديث الصفحة.",
"Error updating contact" => "خطأ في تحديث جهات الاتصال",
"Error saving contact to backend" => "حدث خطأ أثناء حفظ جهات الاتصال في الخلفية.",
"Error getting user photo" => "حدث خطأ أثناء جلب صورة المستخدم",
"No photo path was submitted." => "لم يتم عرض مسار الصورة. \nلم يتم تقديم مسار للصورة. ",
"Error getting PHOTO property." => "خطأ في الحصول على ملكية الصورة.",
"Error saving contact." => "خطأ في حفظ جهة الإتصال.",
"No group name given." => "لم يتم تسمية المجموعة بعد.",
"Error adding group." => "حدث خطأ أثناء إضافة المجموعة,",
"Error renaming group." => "حدث خطأ أثناء إعادة تسمية المجموعة.",
"No file was uploaded. Unknown error" => "لم يتم رفع أي ملف , خطأ غير معروف",
"There is no error, the file uploaded with success" => "تم ترفيع الملفات بنجاح.",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "حجم الملف الذي تريد ترفيعه أعلى مما upload_max_filesize يسمح به في ملف php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "حجم الملف الذي تريد ترفيعه أعلى مما MAX_FILE_SIZE يسمح به في واجهة ال HTML.",
"The uploaded file was only partially uploaded" => "تم ترفيع جزء من الملفات الذي تريد ترفيعها فقط",
"No file was uploaded" => "لم يتم ترفيع أي من الملفات",
"Missing a temporary folder" => "المجلد المؤقت غير موجود",
"Failed to write to disk" => "خطأ في الكتابة على القرص الصلب",
"Not enough storage available" => "لا يوجد مساحة تخزينية كافية",
"Error uploading contacts to storage." => "خطأ في رفع جهات الإتصال للمخزن,",
"Error moving file to imports folder." => "خطأ في نقل الملف إلى مجلد الاستيراد.",
"Could not set preference: " => "تعذر تعيين المفضل ",
"Contact" => "معرفه",
"Other" => "شيء آخر",
"HomePage" => "الصفحة الرئيسية",
"Jabber" => "Jabber",
"Internet call" => "مكالمات عن طريق الإنترنت",
"AIM" => "AIM",
"MSN" => "مراسل MSN",
"Twitter" => "تويتر",
"GoogleTalk" => "جوجل توك للتراسل الفوري و الصوتي",
"Facebook" => "فيسبوك",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "ياهو",
"Skype" => "سكايب",
"QQ" => "كيوكيو",
"GaduGadu" => "قادو قادو البولندي للمراسلة الفورية",
"ownCloud" => "ownCloud",
"Work" => "العمل",
"Home" => "البيت",
"Mobile" => "الهاتف المحمول",
"Text" => "معلومات إضافية",
"Voice" => "صوت",
"Message" => "رسالة",
"Fax" => "الفاكس",
"Video" => "الفيديو",
"Pager" => "الرنان",
"Internet" => "إنترنت",
"Friends" => "الاصدقاء",
"Family" => "العائلة",
"New contact" => "جهة إتصال جديدة",
"Group name" => "اسم المجموعة",
"New group" => "مجموعة جديدة",
"Address books" => "دفتر العناوين",
"Display name" => "اسم العرض",
"Add Address Book" => "أضف دفتر عناوين جديد",
"Automatic format" => "تنسيق تلقائي",
"Select file..." => "تحديد ملف...",
"(De-)select all" => "(De-) تحديد الكل",
"Sort order" => "* ترتيب.\n* فرز.",
"First- Lastname" => "الاسم الأول - العائلة",
"Last-, Firstname" => "العائلة -الاسم الأول",
"Delete" => "إلغاء",
"Groups" => "مجموعات",
"Download" => "تحميل",
"Merge" => "دمج",
"Email" => "البريد الإلكترونى",
"Phone" => "الهاتف",
"Address" => "عنوان",
"Group" => "مجموعة",
"Keyboard shortcuts" => "اختصارات لوحة المفاتيح",
"Navigation" => "تصفح",
"Next contact in list" => "جهة الاتصال التالية في القائمة ",
"Previous contact in list" => "جهة الاتصال السابقة في القائمة ",
"Expand/collapse current addressbook" => "توسيع / طي دفتر العناوين الحالي.",
"Next addressbook" => "دفتر العنوان التالي",
"Previous addressbook" => "دفتر العنوان السابق",
"Actions" => "* تطبيقات.\n* أنشطة.",
"Refresh contacts list" => "تحديث قائمة جهات الاتصال",
"Add new contact" => "أَف جهة اتصال جديدة",
"Add new addressbook" => "أضف دفتر عناوين جديد",
"Delete current contact" => "إزالة جهة الاتصال الحالية",
"Which contact should the data be merged into?" => "إي جهة اتصال ترغب بدمج البيانات إليها؟",
"Delete the other(s) after successful merge?" => "هل تريد إزالة (الآخرون) بعد نجاح عملية الدمج؟",
"Compose mail" => "إنشاء رسالة بريد إلكتروني",
"Delete current photo" => "إزالة الصورة الحالية",
"Edit current photo" => "تحرير الصورة الحالية",
"Upload new photo" => "رفع صورة جديدة",
"Favorite" => "المفضلة",
"Name" => "اسم",
"First name" => "الاسم الأول",
"Additional names" => "الاسماء الإضافية",
"Last name" => "اسم العائلة",
"Address book" => "دفتر العناوين",
"Nickname" => "كنية.\nلقب.",
"Title" => "اللقب",
"Organization" => "المؤسسة",
"Birthday" => "عيد ميلاد",
"Website" => "موقع إلكتروني",
"Notes go here..." => "للملاحظات إذهب هنا...",
"Add field..." => "إضافة حقل ...",
"Instant Messaging" => "التراسل الفوري",
"Note" => "ملاحظة",
"Web site" => "موقع إلكتروني",
"Preferred" => "مفضل",
"Please specify a valid email address." => "يرجى تحديد عنوان إلكتروني صالح للإستخدام.",
"someone@example.com" => "someone@example.com",
"Mail to address" => "إرسال إلى العنوان.",
"Delete email address" => "حذف عنوان البريد الإلكتروني",
"Enter phone number" => "إدخال رقم الهاتف",
"Go to web site" => "الذهاب إلى الموقع الإلكتروني.",
"View on map" => "مشاهدة على الخريطة.",
"Street address" => "عنوان الشارع.",
"Postal code" => "الرمز البريدي.",
"City" => "المدينة",
"State or province" => "الولاية أو المنطقة.",
"Country" => "البلد",
"Instant Messenger" => "رسائل فورية.",
"Active" => "فعال",
"Share" => "شارك",
"Export" => "تصدير",
"CardDAV link" => "رابط - وصلة - CardDA لنقل و مشاركة جهات الاتصال",
"Edit" => "تعديل",
"Description" => "وصف",
"User" => "مستخدم",
"Password" => "كلمة السر"
);
